@@ -1,4 +1,4 @@
-# Copyright 2016-2021 The Van Valen Lab at the California Institute of
+# Copyright 2016-2022 The Van Valen Lab at the California Institute of
 # Technology (Caltech), with support from the Paul Allen Family Foundation,
 # Google, & National Institutes of Health (NIH) under Grant U24CA224309-01.
 # All rights reserved.
@@ -32,7 +32,7 @@ from __future__ import division
 import numpy as np
 from sklearn.model_selection import train_test_split
 from tensorflow.keras import backend as K
-from tensorflow.python.keras.utils import conv_utils
+from keras.utils import conv_utils
 
 from deepcell.utils.tracking_utils import load_trks
 
