@@ -1,4 +1,4 @@
-# Copyright 2016-2021 The Van Valen Lab at the California Institute of
+# Copyright 2016-2022 The Van Valen Lab at the California Institute of
 # Technology (Caltech), with support from the Paul Allen Family Foundation,
 # Google, & National Institutes of Health (NIH) under Grant U24CA224309-01.
 # All rights reserved.
@@ -35,7 +35,7 @@ import numpy as np
 import matplotlib.pyplot as plt
 
 from matplotlib import animation
-from tensorflow.python.keras import backend as K
+from tensorflow.keras import backend as K
 from skimage.exposure import rescale_intensity
 from skimage.segmentation import find_boundaries
 
